package C::D::F;
sub answer { 42 }
1;
